.. _citation-guide:
Citation Guide
==============

If you used asimov in part of your analysis, or it contributed towards results in a paper we'd appreciate it if you would cite the original paper which describes asimov, which was published in the Journal of Open Source Software.

Williams, D. et al., "Asimov: A framework for coordinating parameter estimation workflows", *The Journal of Open Source Software*, vol. 8, no. 84, Art. no. 4170, 2023. doi:10.21105/joss.04170.

BibTeX Entry
------------

.. code-block:: bibtex

   @ARTICLE{asimov-paper,
          author = {{Williams}, Daniel and {Veitch}, John and {Chiofalo}, Maria and {Schmidt}, Patricia and {Udall}, Rhiannon and {Vajpeyi}, Avi and {Hoy}, Charlie},
           title = "{Asimov: A framework for coordinating parameter estimation workflows}",
         journal = {The Journal of Open Source Software},
        keywords = {Python, astronomy, gravitational waves, General Relativity and Quantum Cosmology, Physics - Data Analysis, Statistics and Probability},
            year = 2023,
           month = apr,
          volume = {8},
          number = {84},
             eid = {4170},
           pages = {4170},
             doi = {10.21105/joss.04170},
   archivePrefix = {arXiv},
          eprint = {2207.01468},
    primaryClass = {gr-qc},
   }


Citing specific versions of the software
----------------------------------------

We use Zenodo to publish releases, and each release receives a DOI which can be cited.

These should be cited, where relevant, in addition to the paper above, in the format:

Daniel Williams, Duncan Macleod, Avi Vajpeyi, James Clark, & Richard O'Shaughnessy. (2024). transientlunatic/asimov: v0.5.8 (v0.5.8). Zenodo. https://doi.org/10.5281/zenodo.13992299

(See `this page <https://doi.org/10.5281/zenodo.4024432>`_ for the latest version, and links to previous versions' DOIs, where links to BibTeX snippets for relevant versions are also available).
